@@ -11,7 +11,7 @@ aftreg <- function (formula = formula(data),
                     model = FALSE,
                     x = FALSE,
                     y = TRUE,
-                    center = FALSE)
+                    center = NULL)
 {
 
     if (dist == "gompertz") shape <- 1
@@ -69,14 +69,7 @@ aftreg <- function (formula = formula(data),
     ##return(X)
     assign <- lapply(attrassign(X, newTerms)[-1], function(x) x - 1)
 
-    ##if (dist != "gompertz"){
-      ##  intercept <- FALSE
-    X <- X[, -1, drop = FALSE]
-    ##}else{
-      ##  intercept <- TRUE
-    ##}
-    ##### No more intercept! (1.2-17) !! #############
-
+    X <- X[, -1, drop = FALSE]  ##OBS!!!! No Intercept!
     
     ncov <- NCOL(X)
 
@@ -158,7 +151,7 @@ aftreg <- function (formula = formula(data),
         fit$linear.predictors <- offset + X %*% fit$coefficients[1:ncov]
         fit$means <- apply(X, 2, mean)
     }else{
-        fit$linear.predictors <- NULL
+        fit$linear.predictors <- offset
         fit$means <- NULL
     }
     ##score <- exp(lp)
